@@ -8,7 +8,7 @@ import (
 
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
-	"gopkg.in/yaml.v3"
+	"go.yaml.in/yaml/v3"
 
 	"github.com/securego/gosec/v2"
 	"github.com/securego/gosec/v2/cwe"
@@ -51,9 +51,9 @@ func createReportInfo(rule string, weakness *cwe.Weakness) gosec.ReportInfo {
 }
 
 func stripString(str string) string {
-	ret := strings.Replace(str, "\n", "", -1)
-	ret = strings.Replace(ret, " ", "", -1)
-	ret = strings.Replace(ret, "\t", "", -1)
+	ret := strings.ReplaceAll(str, "\n", "")
+	ret = strings.ReplaceAll(ret, " ", "")
+	ret = strings.ReplaceAll(ret, "\t", "")
 	return ret
 }
 
@@ -83,10 +83,24 @@ var _ = Describe("Formatter", func() {
 				},
 			}
 			want := &sonar.Report{
+				Rules: []*sonar.Rule{
+					{
+						ID:                 "test",
+						Name:               "test",
+						Description:        "test",
+						EngineID:           "gosec",
+						CleanCodeAttribute: "TRUSTWORTHY",
+						Impacts: []*sonar.Impact{
+							{
+								SoftwareQuality: "SECURITY",
+								Severity:        "HIGH",
+							},
+						},
+					},
+				},
 				Issues: []*sonar.Issue{
 					{
-						EngineID: "gosec",
-						RuleID:   "test",
+						RuleID: "test",
 						PrimaryLocation: &sonar.Location{
 							Message:  "test",
 							FilePath: "test.go",
@@ -95,8 +109,6 @@ var _ = Describe("Formatter", func() {
 								EndLine:   2,
 							},
 						},
-						Type:          "VULNERABILITY",
-						Severity:      "BLOCKER",
 						EffortMinutes: sonar.EffortMinutes,
 					},
 				},
@@ -131,10 +143,24 @@ var _ = Describe("Formatter", func() {
 				},
 			}
 			want := &sonar.Report{
+				Rules: []*sonar.Rule{
+					{
+						ID:                 "test",
+						Name:               "test",
+						Description:        "test",
+						EngineID:           "gosec",
+						CleanCodeAttribute: "TRUSTWORTHY",
+						Impacts: []*sonar.Impact{
+							{
+								SoftwareQuality: "SECURITY",
+								Severity:        "HIGH",
+							},
+						},
+					},
+				},
 				Issues: []*sonar.Issue{
 					{
-						EngineID: "gosec",
-						RuleID:   "test",
+						RuleID: "test",
 						PrimaryLocation: &sonar.Location{
 							Message:  "test",
 							FilePath: "subfolder/test.go",
@@ -143,8 +169,6 @@ var _ = Describe("Formatter", func() {
 								EndLine:   2,
 							},
 						},
-						Type:          "VULNERABILITY",
-						Severity:      "BLOCKER",
 						EffortMinutes: sonar.EffortMinutes,
 					},
 				},
@@ -178,6 +202,7 @@ var _ = Describe("Formatter", func() {
 				},
 			}
 			want := &sonar.Report{
+				Rules:  []*sonar.Rule{},
 				Issues: []*sonar.Issue{},
 			}
 
@@ -188,7 +213,7 @@ var _ = Describe("Formatter", func() {
 			Expect(*issues).To(Equal(*want))
 		})
 
-		It("it should parse the report info for multiple projects projects", func() {
+		It("it should parse the report info for multiple projects", func() {
 			data := &gosec.ReportInfo{
 				Errors: map[string][]gosec.Error{},
 				Issues: []*issue.Issue{
@@ -219,10 +244,24 @@ var _ = Describe("Formatter", func() {
 				},
 			}
 			want := &sonar.Report{
+				Rules: []*sonar.Rule{
+					{
+						ID:                 "test",
+						Name:               "test",
+						Description:        "test",
+						EngineID:           "gosec",
+						CleanCodeAttribute: "TRUSTWORTHY",
+						Impacts: []*sonar.Impact{
+							{
+								SoftwareQuality: "SECURITY",
+								Severity:        "HIGH",
+							},
+						},
+					},
+				},
 				Issues: []*sonar.Issue{
 					{
-						EngineID: "gosec",
-						RuleID:   "test",
+						RuleID: "test",
 						PrimaryLocation: &sonar.Location{
 							Message:  "test",
 							FilePath: "test-project1.go",
@@ -231,13 +270,10 @@ var _ = Describe("Formatter", func() {
 								EndLine:   2,
 							},
 						},
-						Type:          "VULNERABILITY",
-						Severity:      "BLOCKER",
 						EffortMinutes: sonar.EffortMinutes,
 					},
 					{
-						EngineID: "gosec",
-						RuleID:   "test",
+						RuleID: "test",
 						PrimaryLocation: &sonar.Location{
 							Message:  "test",
 							FilePath: "test-project2.go",
@@ -246,8 +282,6 @@ var _ = Describe("Formatter", func() {
 								EndLine:   2,
 							},
 						},
-						Type:          "VULNERABILITY",
-						Severity:      "BLOCKER",
 						EffortMinutes: sonar.EffortMinutes,
 					},
 				},
@@ -278,11 +312,44 @@ var _ = Describe("Formatter", func() {
 	})
 	Context("When using different report formats", func() {
 		grules := []string{
-			"G101", "G102", "G103", "G104", "G106", "G107", "G109",
-			"G110", "G111", "G112", "G113", "G201", "G202", "G203",
-			"G204", "G301", "G302", "G303", "G304", "G305", "G401",
-			"G402", "G403", "G404", "G501", "G502", "G503", "G504",
-			"G505", "G601",
+			"G101",
+			"G102",
+			"G103",
+			"G104",
+			"G106",
+			"G107",
+			"G108",
+			"G109",
+			"G110",
+			"G111",
+			"G112",
+			"G114",
+			"G117",
+			"G201",
+			"G202",
+			"G203",
+			"G204",
+			"G301",
+			"G302",
+			"G303",
+			"G304",
+			"G305",
+			"G306",
+			"G401",
+			"G402",
+			"G403",
+			"G404",
+			"G405",
+			"G406",
+			"G407",
+			"G501",
+			"G502",
+			"G503",
+			"G504",
+			"G505",
+			"G506",
+			"G507",
+			"G601",
 		}
 
 		It("csv formatted report should contain the CWE mapping", func() {
@@ -310,7 +377,7 @@ var _ = Describe("Formatter", func() {
 				reportInfo := gosec.NewReportInfo([]*issue.Issue{&newissue}, &gosec.Metrics{NumFiles: 0, NumLines: 0, NumNosec: 0, NumFound: 0}, errors).WithVersion("v2.7.0")
 				err := CreateReport(buf, "xml", false, []string{}, reportInfo)
 				Expect(err).ShouldNot(HaveOccurred())
-				pattern := "Results:\n\n\n[/home/src/project/test.go:1] - %s (CWE-%s): test (Confidence: HIGH, Severity: HIGH)\n  > 1: testcode\n\n\n\nSummary:\n  Gosec  : v2.7.0\n  Files  : 0\n  Lines  : 0\n  Nosec  : 0\n  Issues : 0\n\n"
+				pattern := "Results:\n\n\n[/home/src/project/test.go:1] - %s (CWE-%s): test (Confidence: HIGH, Severity: HIGH)\n  > 1: testcode\n\nAutofix: \n\nSummary:\n  Gosec  : v2.7.0\n  Files  : 0\n  Lines  : 0\n  Nosec  : 0\n  Issues : 0\n\n"
 				expect := fmt.Sprintf(pattern, rule, cwe.ID)
 				Expect(buf.String()).To(Equal(expect))
 			}
@@ -537,5 +604,195 @@ var _ = Describe("Formatter", func() {
 			result := stripString(buf.String())
 			Expect(result).To(ContainSubstring(`"Issues":[{`))
 		})
+
+		It("non-json/sarif formats should filter out suppressed issues", func() {
+			regularIssue := createIssue("G102", issue.GetCweByRule("G102"))
+			errors := map[string][]gosec.Error{}
+			reportInfo := gosec.NewReportInfo([]*issue.Issue{&suppressedIssue, &regularIssue}, &gosec.Metrics{}, errors)
+
+			buf := new(bytes.Buffer)
+			err := CreateReport(buf, "text", false, []string{}, reportInfo)
+			Expect(err).ShouldNot(HaveOccurred())
+
+			result := buf.String()
+			// Should contain the regular issue but processing depends on filtering
+			Expect(result).To(ContainSubstring("Summary"))
+		})
+
+		It("csv format should filter out suppressed issues", func() {
+			regularIssue := createIssue("G102", issue.GetCweByRule("G102"))
+			errors := map[string][]gosec.Error{}
+			reportInfo := gosec.NewReportInfo([]*issue.Issue{&suppressedIssue, &regularIssue}, &gosec.Metrics{}, errors)
+
+			buf := new(bytes.Buffer)
+			err := CreateReport(buf, "csv", false, []string{}, reportInfo)
+			Expect(err).ShouldNot(HaveOccurred())
+			// CSV output should be generated
+			Expect(buf.Len()).To(BeNumerically(">", 0))
+		})
+
+		It("yaml format should filter out suppressed issues", func() {
+			regularIssue := createIssue("G102", issue.GetCweByRule("G102"))
+			errors := map[string][]gosec.Error{}
+			reportInfo := gosec.NewReportInfo([]*issue.Issue{&suppressedIssue, &regularIssue}, &gosec.Metrics{}, errors)
+
+			buf := new(bytes.Buffer)
+			err := CreateReport(buf, "yaml", false, []string{}, reportInfo)
+			Expect(err).ShouldNot(HaveOccurred())
+			// YAML output should be generated
+			Expect(buf.Len()).To(BeNumerically(">", 0))
+		})
+
+		It("junit-xml format should filter out suppressed issues", func() {
+			regularIssue := createIssue("G102", issue.GetCweByRule("G102"))
+			errors := map[string][]gosec.Error{}
+			reportInfo := gosec.NewReportInfo([]*issue.Issue{&suppressedIssue, &regularIssue}, &gosec.Metrics{}, errors)
+
+			buf := new(bytes.Buffer)
+			err := CreateReport(buf, "junit-xml", false, []string{}, reportInfo)
+			Expect(err).ShouldNot(HaveOccurred())
+			// XML output should be generated
+			Expect(buf.Len()).To(BeNumerically(">", 0))
+		})
+
+		It("html format should filter out suppressed issues", func() {
+			regularIssue := createIssue("G102", issue.GetCweByRule("G102"))
+			errors := map[string][]gosec.Error{}
+			reportInfo := gosec.NewReportInfo([]*issue.Issue{&suppressedIssue, &regularIssue}, &gosec.Metrics{}, errors)
+
+			buf := new(bytes.Buffer)
+			err := CreateReport(buf, "html", false, []string{}, reportInfo)
+			Expect(err).ShouldNot(HaveOccurred())
+			// HTML output should be generated
+			Expect(buf.Len()).To(BeNumerically(">", 0))
+		})
+
+		It("sonarqube format should filter out suppressed issues", func() {
+			regularIssue := createIssue("G102", issue.GetCweByRule("G102"))
+			errors := map[string][]gosec.Error{}
+			reportInfo := gosec.NewReportInfo([]*issue.Issue{&suppressedIssue, &regularIssue}, &gosec.Metrics{}, errors)
+
+			buf := new(bytes.Buffer)
+			err := CreateReport(buf, "sonarqube", false, []string{}, reportInfo)
+			Expect(err).ShouldNot(HaveOccurred())
+			// Sonarqube JSON output should be generated
+			Expect(buf.Len()).To(BeNumerically(">", 0))
+		})
+
+		It("golint format should filter out suppressed issues", func() {
+			regularIssue := createIssue("G102", issue.GetCweByRule("G102"))
+			errors := map[string][]gosec.Error{}
+			reportInfo := gosec.NewReportInfo([]*issue.Issue{&suppressedIssue, &regularIssue}, &gosec.Metrics{}, errors)
+
+			buf := new(bytes.Buffer)
+			err := CreateReport(buf, "golint", false, []string{}, reportInfo)
+			Expect(err).ShouldNot(HaveOccurred())
+			// Golint output should be generated
+			Expect(buf.Len()).To(BeNumerically(">", 0))
+		})
+	})
+
+	Context("When using default format", func() {
+		It("should default to text format for unknown format strings", func() {
+			ruleID := "G101"
+			cwe := issue.GetCweByRule(ruleID)
+			testIssue := createIssue(ruleID, cwe)
+			errors := map[string][]gosec.Error{}
+			reportInfo := gosec.NewReportInfo([]*issue.Issue{&testIssue}, &gosec.Metrics{}, errors)
+
+			buf := new(bytes.Buffer)
+			err := CreateReport(buf, "unknown-format", false, []string{}, reportInfo)
+			Expect(err).ShouldNot(HaveOccurred())
+
+			result := buf.String()
+			Expect(result).To(ContainSubstring("Summary"))
+		})
+
+		It("should handle empty format string", func() {
+			ruleID := "G101"
+			cwe := issue.GetCweByRule(ruleID)
+			testIssue := createIssue(ruleID, cwe)
+			errors := map[string][]gosec.Error{}
+			reportInfo := gosec.NewReportInfo([]*issue.Issue{&testIssue}, &gosec.Metrics{}, errors)
+
+			buf := new(bytes.Buffer)
+			err := CreateReport(buf, "", false, []string{}, reportInfo)
+			Expect(err).ShouldNot(HaveOccurred())
+
+			result := buf.String()
+			Expect(result).To(ContainSubstring("Summary"))
+		})
+	})
+
+	Context("When handling empty reports", func() {
+		It("should handle empty issues in json format", func() {
+			errors := map[string][]gosec.Error{}
+			reportInfo := gosec.NewReportInfo([]*issue.Issue{}, &gosec.Metrics{}, errors)
+
+			buf := new(bytes.Buffer)
+			err := CreateReport(buf, "json", false, []string{}, reportInfo)
+			Expect(err).ShouldNot(HaveOccurred())
+
+			var jsonResult map[string]interface{}
+			err = json.Unmarshal(buf.Bytes(), &jsonResult)
+			Expect(err).ShouldNot(HaveOccurred())
+		})
+
+		It("should handle empty issues in yaml format", func() {
+			errors := map[string][]gosec.Error{}
+			reportInfo := gosec.NewReportInfo([]*issue.Issue{}, &gosec.Metrics{}, errors)
+
+			buf := new(bytes.Buffer)
+			err := CreateReport(buf, "yaml", false, []string{}, reportInfo)
+			Expect(err).ShouldNot(HaveOccurred())
+
+			var yamlResult map[string]interface{}
+			err = yaml.Unmarshal(buf.Bytes(), &yamlResult)
+			Expect(err).ShouldNot(HaveOccurred())
+		})
+
+		It("should handle empty issues in text format", func() {
+			errors := map[string][]gosec.Error{}
+			reportInfo := gosec.NewReportInfo([]*issue.Issue{}, &gosec.Metrics{}, errors)
+
+			buf := new(bytes.Buffer)
+			err := CreateReport(buf, "text", false, []string{}, reportInfo)
+			Expect(err).ShouldNot(HaveOccurred())
+
+			result := buf.String()
+			Expect(result).To(ContainSubstring("Summary"))
+		})
+	})
+
+	Context("When handling color output", func() {
+		It("should generate colored output when enabled", func() {
+			ruleID := "G101"
+			cwe := issue.GetCweByRule(ruleID)
+			testIssue := createIssue(ruleID, cwe)
+			errors := map[string][]gosec.Error{}
+			reportInfo := gosec.NewReportInfo([]*issue.Issue{&testIssue}, &gosec.Metrics{}, errors)
+
+			buf := new(bytes.Buffer)
+			err := CreateReport(buf, "text", true, []string{}, reportInfo)
+			Expect(err).ShouldNot(HaveOccurred())
+
+			result := buf.String()
+			Expect(result).ToNot(BeEmpty())
+		})
+
+		It("should generate non-colored output when disabled", func() {
+			ruleID := "G101"
+			cwe := issue.GetCweByRule(ruleID)
+			testIssue := createIssue(ruleID, cwe)
+			errors := map[string][]gosec.Error{}
+			reportInfo := gosec.NewReportInfo([]*issue.Issue{&testIssue}, &gosec.Metrics{}, errors)
+
+			buf := new(bytes.Buffer)
+			err := CreateReport(buf, "text", false, []string{}, reportInfo)
+			Expect(err).ShouldNot(HaveOccurred())
+
+			result := buf.String()
+			Expect(result).ToNot(BeEmpty())
+		})
 	})
 })
